bayespy.nodes.VaryingGaussianMarkovChain.initialize_from_parameters
===================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.initialize_from_parameters